@@ -15,21 +15,17 @@
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-#define CARD_C
 
-#include "../freecell/gdk-card-image/gdk-card-image.h"
+#include "sol.h"
 #include "card.h"
 
 GdkPixmap *default_background_pixmap; 
 GdkPixmap *slot_pixmap;
-GdkPixmap *card_back_pixmap;
 GdkBitmap *mask;
 
-GdkPixmap* get_card_picture(gint suit, gint value ) {
-  GdkPixmap *ret;
-  gdk_card_image(13*((4-suit)%4)+value-1, &ret, NULL); 
-
-  return ret;
+GdkPixmap* get_card_picture (gint suit, gint rank ) 
+{
+  return gdk_card_deck_face (GDK_CARD_DECK (card_deck), suit, rank);
 }
 
 GdkPixmap* get_background_pixmap() {
@@ -41,28 +37,30 @@ GdkPixmap* get_slot_pixmap() {
   return slot_pixmap;
 }
 
-GdkPixmap* get_card_back_pixmap() {
-  return card_back_pixmap;
+GdkPixmap* get_card_back_pixmap () {
+  return gdk_card_deck_back (GDK_CARD_DECK (card_deck));
 }
 
 int get_card_width() {
   int width, height;
-  gdk_window_get_size(card_back_pixmap, &width, &height);
+  gdk_window_get_size(gdk_card_deck_back (GDK_CARD_DECK (card_deck)), 
+		      &width, &height);
   return width;
 }
 
 int get_card_height() {
   int width, height;
-  gdk_window_get_size(card_back_pixmap, &width, &height);
+  gdk_window_get_size(gdk_card_deck_back (GDK_CARD_DECK (card_deck)), 
+		      &width, &height);
   return height;
 }
 
 int get_horiz_offset() {
-  return get_card_width() + HORIZ_SPACING;
+  return get_card_width() + x_spacing;
 }
 
 int get_vert_offset() {
-  return get_card_height() + VERT_SPACING;
+  return get_card_height() + y_spacing;
 }
 
 int get_vert_start() {
@@ -88,15 +86,19 @@ GdkPixmap* get_pixmap (char* filename)
   return ret;
 }
 
-void load_pixmaps(GtkWidget* app) 
+void load_pixmaps(GtkWidget* app, GdkCardDeckOptions deck_options) 
 {
+  card_deck = gdk_card_deck_new (app->window, deck_options);
+  mask = gdk_card_deck_mask (GDK_CARD_DECK (card_deck)); 
+  slot_pixmap = get_pixmap ("cards/slots/plain.png");
+  default_background_pixmap = get_pixmap ("cards/baize.png");
+}
 
-  slot_pixmap = get_pixmap ("cards/Cardback4.xpm");
-  card_back_pixmap = get_pixmap ("cards/Cardback1.xpm");
-  default_background_pixmap = get_pixmap ("cards/Baize.xpm");
-
-  gdk_card_image_init(app->window);
-  gdk_card_image(0, NULL, &mask); 
+void free_pixmaps() 
+{
+  gtk_object_destroy (card_deck);
+  gdk_pixmap_unref (slot_pixmap);
+  gdk_pixmap_unref (default_background_pixmap);
 }
 
 void add_card(GList** card_list, hcard_type temp_card) {
