@@ -3,7 +3,7 @@
 
 void show_select_game_dialog ();
 void show_game_over_dialog ();
-void show_property_dialog ();
+void show_preferences_dialog ();
 void show_rules_options_dialog ();
 void show_global_stats_dialog ();
 void show_rules_stats_dialog ();
