@@ -25,6 +25,7 @@
 #include <dirent.h>
 #include <libguile.h>
 #include <guile/gh.h>
+#include <ctype.h>
 #include "sol.h"
 #include "events.h"
 #include "draw.h"
@@ -106,11 +107,13 @@ gpointer* game_file_to_help_entry (const gchar* file)
 
 void make_title () 
 {
-  gint old_w, old_h;
-  GString* title = g_string_new (game_name);
-  g_string_sprintfa (title, "  ( %d )", seed);
+  char *title;
 
-  gtk_window_set_title (GTK_WINDOW (app), title->str); 
+  title = alloca(strlen(game_name) + 20);
+  
+  sprintf(title, "%s  ( %d )", game_name, seed);
+
+  gtk_window_set_title (GTK_WINDOW (app), title); 
 }
 
 void eval_installed_file (char *file)
@@ -365,6 +368,8 @@ void main_prog(int argc, char *argv[])
   gtk_box_pack_end (GTK_BOX(status_bar), score_box, FALSE, FALSE, 0);
   gnome_app_set_statusbar (GNOME_APP (app), status_bar);
 
+  install_menu_hints(GNOME_APP (app));
+
   new_game (start_game, &seed);
 
   splash_destroy ();
@@ -383,7 +388,6 @@ static int
 save_state (GnomeClient *client)
 {
   gchar *prefix = gnome_client_get_config_prefix (client);
-  gchar *argv[2];
 
   gnome_config_push_prefix (prefix);
   gnome_config_set_string ("Variation/Default File", game_file);
@@ -458,7 +462,7 @@ int main (int argc, char *argv [])
 
   retrieve_state (gnome_master_client ());
 
-  dir = gnome_datadir_file (GAMESDIR);
+  dir = gnome_unconditional_datadir_file (GAMESDIR);
   n_games = scandir (dir, &game_dents, is_game, alphasort);
   g_free(dir);
 
