@@ -1,6 +1,6 @@
 /* gnome-stones - main.c
  *
- * Time-stamp: <1998/11/28 13:39:56 hvr>
+ * Time-stamp: <1999/01/10 05:56:18 ndf>
  *
  * Copyright (C) 1998 Carsten Schaar
  *
@@ -412,7 +412,6 @@ game_widget_key_press_callback (GtkWidget   *widget,
 	    {
 	      start_cave++;
 	      game_update_title ();
-	      preferences_save ();
 	    }
 	  return TRUE;
 	}
@@ -448,7 +447,6 @@ game_widget_key_press_callback (GtkWidget   *widget,
 	    {
 	      start_cave--;
 	      game_update_title ();
-	      preferences_save ();
 	    }
 	  return TRUE;
 	}
@@ -1123,13 +1121,15 @@ game_start_cb (GtkWidget *widget, gpointer data)
 static void
 preferences_cb (GtkWidget *widget, gpointer data)
 {
-  gtk_widget_show (preferences_dialog_new ());
+  preferences_dialog_show ();
 }
 
 
 static void
 quit_cb (GtkWidget *widget, gpointer data)
 {
+  preferences_save_global ();
+
   exit (0);
 }
 
@@ -1165,57 +1165,38 @@ about_cb (GtkWidget *widget, gpointer data)
 /* Menu definitions */
 
 
+static GnomeUIInfo file_menu[]= {
+  GNOMEUIINFO_MENU_EXIT_ITEM(quit_cb, NULL),
+  GNOMEUIINFO_END
+};
+
 static GnomeUIInfo game_menu[]= {
-  {
-    GNOME_APP_UI_ITEM,
-    N_("_New"), N_("Start a new game"),
-    game_start_cb, NULL, NULL,
-    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
-    GNOME_KEY_NAME_NEW, GNOME_KEY_MOD_NEW, NULL
-  },
-  {
-    GNOME_APP_UI_ITEM,
-    N_("_Scores..."), N_("Show highscore table"),
-    show_scores_cb, (gpointer) 0, NULL,
-    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SCORES,
-    0, (GdkModifierType) 0, NULL
-  },
+  GNOMEUIINFO_MENU_NEW_GAME_ITEM(game_start_cb, NULL),
+
   GNOMEUIINFO_SEPARATOR,
-  {
-    GNOME_APP_UI_ITEM,
-    N_("_Preferences..."), N_("Change Gnome-Stones preferences"),
-    preferences_cb, (gpointer) 0, NULL,
-    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF,
-    0, (GdkModifierType) 0, NULL
-  },
-  GNOMEUIINFO_SEPARATOR,
-  {
-    GNOME_APP_UI_ITEM,
-    N_("E_xit"), N_("Exit Gnome Stones"),
-    quit_cb, NULL, NULL,
-    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_QUIT,
-    GNOME_KEY_NAME_EXIT, GNOME_KEY_MOD_EXIT, NULL
-  },
+
+  GNOMEUIINFO_MENU_SCORES_ITEM(show_scores_cb, NULL),
+
   GNOMEUIINFO_END
 };
 
 static GnomeUIInfo help_menu[]= {
-  {
-    GNOME_APP_UI_ITEM,
-    N_("_About Gnome-Stones"), N_("Info about Gnome Stones"),
-    about_cb, NULL, NULL,
-    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
-    0, (GdkModifierType) 0, NULL
-  },
-  GNOMEUIINFO_SEPARATOR,
   GNOMEUIINFO_HELP(APP_NAME),
+  GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb, NULL),
+  GNOMEUIINFO_END
+};
+
+static GnomeUIInfo settings_menu[]= {
+  GNOMEUIINFO_MENU_PREFERENCES_ITEM(preferences_cb, NULL),
   GNOMEUIINFO_END
 };
 
 static GnomeUIInfo main_menu[]= 
 {
-  GNOMEUIINFO_SUBTREE(N_("_Game"), game_menu),
-  GNOMEUIINFO_SUBTREE(N_("_Help"), help_menu),
+  GNOMEUIINFO_MENU_FILE_TREE(file_menu),
+  GNOMEUIINFO_MENU_GAME_TREE(game_menu),
+  GNOMEUIINFO_MENU_SETTINGS_TREE(settings_menu),
+  GNOMEUIINFO_MENU_HELP_TREE(help_menu),
   GNOMEUIINFO_END
 };
 
@@ -1364,7 +1345,8 @@ main (int argc, char *argv[])
 
   /* That's what a gnome application needs:  */
   app= gnome_app_new ("gnome-stones", _("Gnome-Stones"));
-  gtk_window_set_policy (GTK_WINDOW (app), FALSE, FALSE, TRUE);
+  gtk_window_set_policy  (GTK_WINDOW (app), FALSE, FALSE, TRUE);
+  gtk_window_set_wmclass (GTK_WINDOW (app), "gnome-stones", "main");
 
   /* ... a menu line, ... */
   gnome_app_create_menus   (GNOME_APP (app), main_menu);
@@ -1378,6 +1360,8 @@ main (int argc, char *argv[])
 
   gnome_appbar_set_default (GNOME_APPBAR (statusbar), _(default_message));
 
+  gnome_app_install_menu_hints(GNOME_APP (app), main_menu);
+
   /* and, last but not least the game display.  */
   vbox = gtk_vbox_new (FALSE, 0);
   
@@ -1396,8 +1380,7 @@ main (int argc, char *argv[])
   
   gnome_app_set_contents (GNOME_APP (app), vbox);
   
-  gtk_widget_set_events (app, gtk_widget_get_events (app) | 
-			 GAME_EVENTS);
+  gtk_widget_set_events (app, gtk_widget_get_events (app) | GAME_EVENTS);
 
   gtk_signal_connect (GTK_OBJECT (app), "key_press_event",
 		      GTK_SIGNAL_FUNC (game_widget_key_press_callback), 0);
