@@ -19,10 +19,15 @@
  * For more details see the file COPYING.
  */
 
+#define MAX_DEPTH 4;
+
 gint is_valid_move(guint, guint, guint);
+gint is_valid_move_board(gint8[8][8], guint, guint, guint);
 gint move(guint, guint, guint);
+gint move_board(gint8[8][8], guint, guint, guint, gint);
 gint count_pieces(gint);
 gint flip_final_results();
 gint check_valid_moves();
 gint computer_move_1(guint);
 gint computer_move_3(guint);
+gint eval_board(gint8[8][8], guint);
