@@ -1,6 +1,6 @@
 /*
  * Gnome-Mahjongg
- * (C) 1998 the Free Software Foundation
+ * (C) 1998-1999 the Free Software Foundation
  *
  *
  * Author: Francisco Bustamante
@@ -25,7 +25,8 @@
 #include "mahjongg.h"
 #include "solubility.h"
 
-#include "button-images.h"
+/* The number of half-cycles to blink during a hint (less 1) */
+#define HINT_BLINK_NUM 5
 
 typeinfo type_info [MAX_TILES+70] = {
   	{ 0, 0, {0, 0} },
@@ -297,7 +298,7 @@ int ypos_offset;
 
 tile tiles[MAX_TILES];
 
-GtkWidget *window, *pref_dialog, *hint_dialog;
+GtkWidget *window, *pref_dialog, *hint_dialog, *appbar;
 GtkWidget *mbox;
 GtkWidget *canvas;
 GtkWidget *tiles_label;
@@ -336,7 +337,7 @@ struct _maps
 
 gint hint_tiles[2];
 guint timer;
-guint timeout_counter = 0;
+guint timeout_counter = HINT_BLINK_NUM + 1;
 
 void clear_undo_queue ();
 void you_won (void);
@@ -358,71 +359,58 @@ void show_tb_callback (GtkWidget *widget, gpointer data);
 void sound_on_callback (GtkWidget *widget, gpointer data);
 
 
-GnomeUIInfo filemenu [] = {
-         {GNOME_APP_UI_ITEM, N_("_New"), NULL, new_game_callback, NULL, NULL,
-         GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW, 'n', GDK_CONTROL_MASK, NULL},
+GnomeUIInfo gamemenu [] = {
+         GNOMEUIINFO_MENU_NEW_GAME_ITEM(new_game_callback, NULL),
 
-         {GNOME_APP_UI_ITEM, N_("New _Seed..."), NULL, select_game_callback, NULL, NULL,
-         GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW, 0, 0, NULL},
+         {GNOME_APP_UI_ITEM, N_("New _seed..."), NULL,
+	  select_game_callback, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	  GNOME_STOCK_MENU_NEW, 0, 0, NULL},
 
-         {GNOME_APP_UI_ITEM, N_("_Restart"), NULL, restart_game_callback, NULL, NULL,
-         GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_REFRESH, 0, 0, NULL},
+	 GNOMEUIINFO_MENU_RESTART_GAME_ITEM(restart_game_callback, NULL),
 
-         {GNOME_APP_UI_SEPARATOR},
+	 GNOMEUIINFO_SEPARATOR,
 
-         {GNOME_APP_UI_ITEM, N_("_Hint"), NULL, hint_callback, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
+	 GNOMEUIINFO_MENU_UNDO_MOVE_ITEM(undo_tile_callback, NULL),
 
-         {GNOME_APP_UI_ITEM, N_("_Undo"), NULL, undo_tile_callback, NULL, NULL,
-         GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_UNDO, 'z', GDK_CONTROL_MASK, NULL},
+	 GNOMEUIINFO_MENU_HINT_ITEM(hint_callback, NULL),
 
-         {GNOME_APP_UI_SEPARATOR},
-	
-         {GNOME_APP_UI_ITEM, N_("E_xit"), NULL, quit_game_callback, NULL, NULL,
-         GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'x', GDK_CONTROL_MASK, NULL},
-
-         {GNOME_APP_UI_ENDOFINFO}
+	 GNOMEUIINFO_END
 };
 
-GnomeUIInfo optionsmenu [] = {
-	{GNOME_APP_UI_TOGGLEITEM, N_("Show _Tool Bar"), NULL, show_tb_callback, NULL, NULL,
-	 GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
+GnomeUIInfo filemenu [] = {
+         GNOMEUIINFO_MENU_EXIT_ITEM(quit_game_callback, NULL),
+	 GNOMEUIINFO_END
+};
 
-        {GNOME_APP_UI_SEPARATOR},
+GnomeUIInfo settingsmenu [] = {
+        GNOMEUIINFO_TOGGLEITEM(N_("Show _Tool Bar"),
+			       N_("Toggle display of the toolbar"),
+			       show_tb_callback, NULL),
+
+	GNOMEUIINFO_SEPARATOR,
 
 #ifdef SOUND_SUPPORT_FINISHED
         {GNOME_APP_UI_TOGGLEITEM, N_("_Sound"), NULL, NULL, NULL, NULL,
         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
 #endif
 
-        {GNOME_APP_UI_ITEM, N_("_Properties..."), NULL, properties_callback, NULL, NULL,
-        GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PROP, 0, 0, NULL},
-
-        
-        {GNOME_APP_UI_ENDOFINFO}
+	GNOMEUIINFO_MENU_PREFERENCES_ITEM(properties_callback, NULL),
+	GNOMEUIINFO_END
 };
 
 GnomeUIInfo helpmenu[] = {
-/* 	{GNOME_APP_UI_HELP, NULL, NULL, NULL, NULL, NULL, */
-/*         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}, */
-	
-	{GNOME_APP_UI_ITEM, N_("_About Mahjongg"), NULL, about_callback, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0, NULL},
-	
-	{GNOME_APP_UI_ENDOFINFO}
+        GNOMEUIINFO_HELP("mahjongg"),
+	GNOMEUIINFO_MENU_ABOUT_ITEM(about_callback, NULL),
+	GNOMEUIINFO_END
+
 };
 
 GnomeUIInfo mainmenu [] = {
-	{GNOME_APP_UI_SUBTREE, N_("_Game"), NULL, filemenu, NULL, NULL,
-	 GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-
-         {GNOME_APP_UI_SUBTREE, N_("_Options"), NULL, optionsmenu, NULL, NULL,
-	 GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-	
-	{GNOME_APP_UI_SUBTREE, N_("_Help"), NULL, helpmenu, NULL, NULL,
-	 GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-	
-	{GNOME_APP_UI_ENDOFINFO}
+        GNOMEUIINFO_MENU_FILE_TREE(filemenu),
+	GNOMEUIINFO_MENU_GAME_TREE(gamemenu),
+	GNOMEUIINFO_MENU_SETTINGS_TREE(settingsmenu),
+	GNOMEUIINFO_MENU_HELP_TREE(helpmenu),
+	GNOMEUIINFO_END
 };
 
 GnomeUIInfo toolbar_uiinfo [] = {
@@ -464,6 +452,7 @@ pref_cancel (GtkWidget *widget, void *data)
 	pref_dialog = 0;
 }
 
+#ifdef NEED_UNUSED_CODE
 static void
 hint_cancel (GtkWidget *widget, void *data)
 {
@@ -478,6 +467,7 @@ hint_cancel (GtkWidget *widget, void *data)
   gtk_widget_destroy (hint_dialog);
   hint_dialog = 0;
 }
+#endif
 
 static void
 set_tile_selection (GtkWidget *widget, void *data)
@@ -546,7 +536,7 @@ change_tile_image (tile *tile_inf) {
 	orig_x = (tile_inf->image % 21) * TILE_WIDTH;
 	orig_y = (tile_inf->image / 21) * TILE_HEIGHT;
 
-	if ((tile_inf->selected == 1) || (tile_inf->selected == 17)) {
+	if (tile_inf->selected) {
 		orig_y += 2 * TILE_HEIGHT;
 	}
 
@@ -565,9 +555,9 @@ tile_event (GnomeCanvasItem *item, GdkEvent *event, tile *tile_inf)
   switch(event->type) {
 	  case GDK_BUTTON_PRESS :
 	    if((event->button.button == 1) && tile_free(tile_inf->number)) {
-	      if (tile_inf->selected == 1) {
+	      if (tile_inf->selected & SELECTED_FLAG) {
 		selected_tile = MAX_TILES + 1;
-		tile_inf->selected = 0;
+		tile_inf->selected &= ~SELECTED_FLAG;
 		change_tile_image (tile_inf);
 	      }
 	      else {
@@ -575,7 +565,7 @@ tile_event (GnomeCanvasItem *item, GdkEvent *event, tile *tile_inf)
 		  if ((tiles[selected_tile].type == tile_inf->type) && tile_free (tile_inf->number)) {
 		    tiles[selected_tile].visible = 0;
 		    tile_inf->visible = 0;
-		    tiles[selected_tile].selected = 0;
+		    tiles[selected_tile].selected &= ~SELECTED_FLAG;
 		    change_tile_image (&tiles[selected_tile]);
 		    gnome_canvas_item_hide (tiles[selected_tile].image_item);
 		    gnome_canvas_item_hide (tile_inf->image_item);
@@ -594,7 +584,7 @@ tile_event (GnomeCanvasItem *item, GdkEvent *event, tile *tile_inf)
 		    no_match ();
 		}
 		else if (tile_free(tile_inf->number)) {
-		  tile_inf->selected = 1;
+		  tile_inf->selected |= SELECTED_FLAG;
 		  change_tile_image(tile_inf);
 		  selected_tile = tile_inf->number;
 		}
@@ -939,22 +929,16 @@ void properties_callback (GtkWidget *widget, gpointer data)
 
 gint hint_timeout (gpointer data)
 {
-  if (timeout_counter <= 4) {
-    if (tiles[hint_tiles[0]].selected == 17) {
-      tiles[hint_tiles[0]].selected = 0;
-      tiles[hint_tiles[1]].selected = 0;
-    }
-    else {
-      tiles[hint_tiles[0]].selected = 17;
-      tiles[hint_tiles[1]].selected = 17;
-    }
-    change_tile_image(&tiles[hint_tiles[0]]);
-    change_tile_image(&tiles[hint_tiles[1]]);
-  }
-  else {
-    gtk_timeout_remove (timer);
-  }
   timeout_counter ++;
+  
+  if (timeout_counter > HINT_BLINK_NUM)
+    return 0;
+  
+  tiles[hint_tiles[0]].selected ^= HINT_FLAG;
+  tiles[hint_tiles[1]].selected ^= HINT_FLAG;
+  change_tile_image(&tiles[hint_tiles[0]]);
+  change_tile_image(&tiles[hint_tiles[1]]);
+
   return 1;
 }
 
@@ -964,6 +948,11 @@ void hint_callback (GtkWidget *widget, gpointer data)
 
   if (hint_dialog)
     return;
+  /* This prevents the flashing speeding up if the hint button is
+   * pressed multiple times. */
+  
+  if (timeout_counter<=HINT_BLINK_NUM) 
+    return;
 
   /* Snarfed from check free
    * Tile Free is now _so_ much quicker, it is more elegant to do a
@@ -983,10 +972,8 @@ void hint_callback (GtkWidget *widget, gpointer data)
 	    free = (tiles[j].type == type && i != j && tile_free(j)) ;
 	    if (free)
 	      {
-		if (!tiles[i].selected)
-		  tiles[i].selected = 17 ;
-		if (!tiles[j].selected)
-		  tiles[j].selected = 17 ;
+		tiles[i].selected ^= HINT_FLAG;
+		tiles[j].selected ^= HINT_FLAG;
 		change_tile_image (&tiles[i]);
 		change_tile_image (&tiles[j]);
 		hint_tiles[0] = i;
@@ -1123,8 +1110,8 @@ void undo_tile_callback (GtkWidget *widget, gpointer data)
 static void
 input_callback (GtkWidget *widget, gpointer data)
 {
-	srand (atoi (GTK_ENTRY (data)->text));
-	new_game ();
+  srand (atoi ((char *)(GTK_ENTRY (data)->text)));
+  new_game ();
 }
 
 static void
@@ -1186,15 +1173,15 @@ void show_tb_callback (GtkWidget *widget, gpointer data)
     gdi = gnome_app_get_dock_item_by_name (GNOME_APP (window), GNOME_APP_TOOLBAR_NAME);
     toolbar = gnome_dock_item_get_child (gdi);
 
-    if((GTK_CHECK_MENU_ITEM(optionsmenu[0].widget))->active)
+    if((GTK_CHECK_MENU_ITEM(settingsmenu[0].widget))->active)
     {
         gnome_config_set_bool("gmahjongg/toolbar/show", TRUE);
-        gtk_widget_show(gdi);
+        gtk_widget_show(GTK_WIDGET(gdi));
     }
     else
     {
         gnome_config_set_bool("gmahjongg/toolbar/show", FALSE);
-        gtk_widget_hide(gdi);
+        gtk_widget_hide(GTK_WIDGET(gdi));
     }
 }
 
@@ -1250,7 +1237,7 @@ void set_map (char *name)
 void create_canvas_items (void)
 {
   GdkImlibImage *image;
-  gint orig_x, orig_y, i, layer, max_x, tile_was_set = 0;
+  gint orig_x, orig_y, i, layer;
   
   for (layer = 0; layer < 7; layer ++) {
     for (i = MAX_TILES - 1; i >= 0; i --) {
@@ -1325,7 +1312,6 @@ void load_tiles (char *fname)
 
 void create_mahjongg_board (void)
 {
- 	GtkStyle *style;
 	gchar *buf;
 	
 	gtk_widget_push_visual (gdk_imlib_get_visual ());
@@ -1398,16 +1384,24 @@ int main (int argc, char *argv [])
 	window = gnome_app_new ("gmahjongg", _("Gnome Mahjongg"));
 /*	gtk_window_set_policy (GTK_WINDOW (window), FALSE, FALSE, TRUE); */
 
+	appbar = gnome_appbar_new (FALSE, TRUE, GNOME_PREFERENCES_USER);
+	gnome_app_set_statusbar (GNOME_APP (window), appbar);
+
+	gnome_appbar_set_status(GNOME_APPBAR (appbar),
+				_("Welcome to Gnome Mahjongg!"));
+
 	gnome_app_create_menus (GNOME_APP (window), mainmenu);
+	gnome_app_install_menu_hints(GNOME_APP (window), mainmenu);
+
         gnome_app_create_toolbar (GNOME_APP (window), toolbar_uiinfo);
 	gdi = gnome_app_get_dock_item_by_name (GNOME_APP (window), GNOME_APP_TOOLBAR_NAME);
 	toolbar = gnome_dock_item_get_child (gdi);
         gtk_toolbar_set_space_size(GTK_TOOLBAR (toolbar), 25);
         
         if(gnome_config_get_bool("/gmahjongg/toolbar/show=TRUE"))
-            gtk_check_menu_item_set_state(GTK_CHECK_MENU_ITEM(optionsmenu[0].widget), TRUE);
+            gtk_check_menu_item_set_state(GTK_CHECK_MENU_ITEM(settingsmenu[0].widget), TRUE);
         else
-	    gtk_widget_hide(gdi);
+	    gtk_widget_hide(GTK_WIDGET(gdi));
 
         tiles_label = gtk_label_new(_("Tiles"));
         gtk_widget_show(tiles_label);
